﻿---
title: "PandocでMarkdownから業務文書.docxを作る"
subtitle: "引き継ぎのためにはWordで残さざるを得ない"
date: "2024-11-02"
author: "日下部幽考"
---


## 概要

このファイル群は、業務文書をMarkdownで執筆し、Pandocを通してMicrosoft Word形式にするためのものである。Markdownはテキストエディタによってテキストファイルとして書けるため、Microsoft Wordの将来の価格・存続にかかわらず保存できる。

次のような読者を想定する。

- Pandocの導入が済んでいる。
- Markdownの記法を知っている。


## 背景

私は教員として働いている。
職場では、業務にかかる文書はMicrosoft Wordで作ることが暗黙の了解となっている。しかし、Microsoft Wordは重さ・お節介・保守性などの面で気になる点がある。また、もしも社会情勢上または職場環境上の理由からMicrosoft Wordが使えなくなったとき、失われるものは計り知れない。

そこで、Microsoft Wordは出力結果にとどめ、テキストデータとして文書を作るための環境を整えたい。



## 解決

Readme.docxはReadme.mdからMake_Docx_Document.batで（pandocを使って）処理したものである。


### 共通の仕様

- BIZ UDフォントを既定としている。
- 強調は日本語らしい設定にできていない。出力したファイルをWordで開くと、スタイルの欄に__emという名のスタイルが用意されている。これを使ってもらいたい。
- 箇条書きは適切に設定できていない（compactスタイルを書き換えることで実現しているため）。本来のcompactスタイル用途としては、代わりに_originalcompactスタイルを使うことができる。また、箇条書きのネストもうまく働かない。第２階層以降は、「インデントを増やす」により手動で調整する。
- 日本語と英語・数字の間は自動調整しない。ベタ組の仕上がりを優先している。


### @document.md + Template_Document.docx

内部向け資料を書くためのテンプレートである。

- titleに文書タイトルを書く。
- subtitleも使える。空欄にしておくと省かれる。
- dateに日付を書く。形式は何でもよい。
- authorに作成者名を書く。
- １番目の見出しはタイトルと同じ体裁を出力する。基本的には、２番目の見出しから使うことを想定している。これは、strict.mdと原稿を互換にするための措置である。


### @strict.md + Template_Strict.docx

外部向け資料を書くためのテンプレートである。

- title, date, authorは適切な位置に配置できないため、これらは使わない。
- 日付・宛名・発行者名は地の文となっている。生成されたファイルをWordで開くと、スタイルの欄に準備されているため、これを用いる。@Authorが発行者名、@Dateが日付、@Toが宛名である。


### Make_Docx_Document.bat

@document.mdに従って書かれたNAME.mdファイルをドラッグアンドドロップすると、同じフォルダにNAME.docxが生成される。

Template_Document.docxと同じフォルダに置く。使いやすい（ドラッグ＆ドロップが楽な）場所にショートカットを置くことを想定している。


### Make_Docx_Strict.bat

@strict.mdに従って書かれたNAME.mdファイルをドラッグアンドドロップすると、同じフォルダにNAME.docxが生成される。

Template_Strict.docxと同じフォルダに置く。使いやすい（ドラッグ＆ドロップが楽な）場所にショートカットを置くことを想定している。


## 補足

Markdownからきれいな文書を出力することが目的であれば、LuaLaTeXを経由してPDFを出力することをすすめたい。このファイル群は、職場内における共有のためにWordファイルにせねばならないことを念頭に作られている。

- 最新の情報：  
<https://www.metaphysica.info/technote/md2docxonwork/>
- 連絡先：  
<https://twitter.com/metaphysicainfo>
- MIT license
- Copyright (c) 2022 Yukoh KUSAKABE

改変は一切自由である。


## 参考

- [日本語Markdownユーザー会](https://www.markdown.jp/)
- [日本Pandocユーザ会](https://pandoc-doc-ja.readthedocs.io/)
- [Pandoc.org](https://pandoc.org/)


## 改訂

- **改訂**：　2024-11-02
	- 用紙サイズをB5判からA4判へ変更。それに伴いフォントサイズを変更。B5印刷は、プリンタの出力用紙機能またはPDFを経由することを想定している。
	- ヘッダ・見出しをはじめとするプロポーショナルフォントを等幅フォントへ変えた。
	- 見出しの体裁を変えた。
	- Document (Modern) において、AuthorとDateの位置を変えた。
	- Document (Modern) において、偶数ページと奇数ページの体裁を揃えた。
- **公開**：　2022-07-29
	- 初回公開版である。

注意：　この箇条書き第２階層は、「インデントを増やす」により手動で調整した。